import customtkinter as ctk
from tkinter import messagebox
from PIL import ImageTk
from utils.api_requests import fetch_shop_details, fetch_shop_products, load_image_from_url

def view_shop_frame(parent, switch_func, API_URL, token):
    frame = ctk.CTkFrame(parent)

    # Title
    title_label = ctk.CTkLabel(frame, text="Your Shop", font=("Helvetica", 18, "bold"))
    title_label.pack(pady=10)

    # Shop Details
    shop_name_label = ctk.CTkLabel(frame, text="Shop Name: ", font=("Helvetica", 14, "bold"))
    shop_name_label.pack(pady=5)

    shop_description_label = ctk.CTkLabel(frame, text="Description: ", font=("Helvetica", 12))
    shop_description_label.pack(pady=5)

    shop_image_label = ctk.CTkLabel(frame, text="")  # Placeholder for shop image
    shop_image_label.pack(pady=10)

    # Product List Section
    product_list_frame = ctk.CTkFrame(frame)
    product_list_frame.pack(fill="both", expand=True, padx=10, pady=10)

    def fetch_and_display_shop():
        """Fetch shop details and update UI"""
        shop_data = fetch_shop_details(API_URL, token)

        if "error" in shop_data:
            messagebox.showerror("Error", shop_data["error"])
            return

        shop_name_label.configure(text=f"Shop Name: {shop_data['name']}")
        shop_description_label.configure(text=f"Description: {shop_data.get('description', 'No description')}")

        if "image_url" in shop_data and shop_data["image_url"]:
            image = load_image_from_url(shop_data["image_url"])
            if image:
                img_tk = ImageTk.PhotoImage(image)
                shop_image_label.configure(image=img_tk, text="")
                shop_image_label.image = img_tk  # Prevent garbage collection

        fetch_and_display_products(shop_data["id"])

    def fetch_and_display_products(shop_id):
        """Fetch products and display them in the UI"""
        products = fetch_shop_products(API_URL, token, shop_id)

        if "error" in products:
            messagebox.showerror("Error", products["error"])
            return

        for widget in product_list_frame.winfo_children():
            widget.destroy()

        if not products:
            ctk.CTkLabel(product_list_frame, text="No products found.", font=("Helvetica", 12)).pack(pady=10)
            return

        for product in products:
            product_frame = ctk.CTkFrame(product_list_frame)
            product_frame.pack(fill="x", padx=5, pady=5)

            # Product Image
            img_label = ctk.CTkLabel(product_frame, text="")  # Placeholder
            img_label.pack(side="left", padx=5)

            if "images" in product and product["images"]:
                image_url = product["images"][0]["image_url"]
                image = load_image_from_url(image_url, size=(50, 50))
                if image:
                    img_tk = ImageTk.PhotoImage(image)
                    img_label.configure(image=img_tk, text="")
                    img_label.image = img_tk  # Prevent garbage collection

            # Product Details
            details_frame = ctk.CTkFrame(product_frame)
            details_frame.pack(side="left", fill="x", expand=True, padx=10)

            ctk.CTkLabel(details_frame, text=product["name"], font=("Helvetica", 12, "bold")).pack(anchor="w")
            ctk.CTkLabel(details_frame, text=f"Price: ${product['price']:.2f}", font=("Helvetica", 12)).pack(anchor="w")

    # Refresh Button
    refresh_button = ctk.CTkButton(frame, text="Refresh", command=fetch_and_display_shop)
    refresh_button.pack(pady=10)

    # Back Button
    back_button = ctk.CTkButton(frame, text="Back", command=lambda: switch_func("login"))
    back_button.pack(pady=10)

    # Fetch shop data on load
    fetch_and_display_shop()

    return frame
